#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVIDES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVIDES_HPP_INCLUDED

#include <boost/simd/operator/include/functions/divides.hpp>

#endif
